<?php
/**
 {{COPYRIGHT_NOTICE}}
 */

/**
 * @inheritdoc
 */
class Montonio_Gateway_Block_Payments_Adminhtml_Source_AvailableMethods extends Mage_Adminhtml_Block_System_Config_Form_Field_Array_Abstract
{
    /**
     * @inheritdoc
     */
    public function __construct()
    {
        $this->addColumn('method_country', [
            'label' => Mage::helper('montonio')->__('Country'),
            'style' => 'width: 25px'
        ]);

        $this->addColumn('method_enabled', [
            'label' => Mage::helper('montonio')->__('On/Off'),
            'style' => 'width: 50px'
        ]);

        $this->addColumn('method_title', [
            'label' => Mage::helper('montonio')->__('Title'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_desc', [
            'label' => Mage::helper('montonio')->__('Description'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('logo_url', [
            'label' => Mage::helper('montonio')->__('Logo Url'),
            'style' => 'width: 150px'
        ]);


        $this->addColumn('method_sort', [
            'label' => Mage::helper('montonio')->__('Sort Order'),
            'style' => 'width: 50px'
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = Mage::helper('montonio')->__('Add label');

        parent::__construct();

        $this->setTemplate('montonio/array.phtml');
    }

    /**
     * @inheritdoc
     */
    protected function _renderCellTemplate($columnName)
    {
        if ($columnName != 'method_enabled') {
            return parent::_renderCellTemplate($columnName);
        }

        if (empty($this->_columns[$columnName])) {
            throw new Exception('Wrong column name specified.');
        }

        $column = $this->_columns[$columnName];
        $inputName = $this->getElement()->getName() . '[#{_id}][' . $columnName . ']';

        if ($column['renderer']) {
            return $column['renderer']->setInputName($inputName)
                ->setColumnName($columnName)
                ->setColumn($column)
                ->toHtml();
        }

        $options = [
            '0' => Mage::helper('montonio')->__('Off'),
            '1' => Mage::helper('montonio')->__('On')
        ];

        $optionsHtml = '';
        foreach ($options as $k => $v) {
            $optionsHtml .= '<option value="' . $k . '">' . $v  . '</option>';
        }
        $styleHtml = (isset($column['style']) ? ' style="' . $column['style'] . '"' : '');
        $cssHtml = (isset($column['class']) ? $column['class'] : 'input-select');
        $selectHtml = '<select data-selected-value="#{method_enabled}" name="' . $inputName . '" class="' . $cssHtml . '"' . $styleHtml . '>' . $optionsHtml . '</select>';

        return $selectHtml;
    }

    /**
     * @inheritdoc
     */
    protected function _prepareArrayRow(Varien_Object $row)
    {
    }

    /**
     * @inheritdoc
     */
    public function getArrayRows()
    {
        $values = $this->getElement()->getValue();

        if (!is_array($values)) {
            $values = [];
        }

        try {

            $methods = Mage::getModel('montonio/method_payments')->aspspsCommand();

            $subMethods = [];
            $uniqueMethods = [];
            $prevCountry = '';

            foreach ($methods as $country => $method) {
                foreach ($method as $k => $v) {
                    //record the key position as bic
                    $uniqueMethods[$country][$v['bic']] = $k;
                    //some methods have overlapping codes, move those to INT (as international)
                    //check if the same code exists in previous country
                    if (isset($uniqueMethods[$prevCountry][$v['bic']])) {
                        $v['method_country'] = Montonio_Gateway_Model_Method_Payments::METHOD_ALL_COUNTRIES;
                    } else {
                        $v['method_country'] = $country;
                    }
                    $subMethods[$v['bic']] = $v;
                }
                //record the prev country for duplicate detection
                $prevCountry = $country;
            }

            $sort = 800;
            foreach ($subMethods as $k => $v) {
                if (!isset($values[$v['bic']])) {
                    $values[$v['bic']] = [
                        'method_country'=> $v['method_country'],
                        'method_enabled'=> '1',
                        'method_title'=> $v['name'],
                        'method_desc' => $v['name'],
                        'logo_url'    => $v['logo_url'],
                        'method_sort' => $sort,
                    ];

                }
                $sort = $sort + 10;
            }
        } catch (\Exception $e) {
            //silence
            $this->silence();
        }

        $this->getElement()->setValue($values);

        return parent::getArrayRows();
    }

    /**
     * get array rows grouped by country
     *
     * @return array
     */
    public function getArrayRowsByCountry() {
        $flatRows = $this->getArrayRows();

        $groupedRows = [];

        foreach ($flatRows as $k => $v) {
            if(isset($v['method_country'])) {
                $groupedRows[$v['method_country']][$k] = $v;
            }
        }
        ksort($groupedRows);

        return $groupedRows;
    }

    /**
     * Do nothing
     * @return void
     */
    public function silence()
    {
    }
}
