<?php
/**
{{COPYRIGHT_NOTICE}}
 */

/**
 * @inheritdoc
 */
class Montonio_Gateway_Block_Payments_Adminhtml_Source_AvailableSplitMethods extends Mage_Adminhtml_Block_System_Config_Form_Field_Array_Abstract
{
    /**
     * @inheritdoc
     */
    public function __construct()
    {
        $this->addColumn('method_label', [
            'label' => Mage::helper('montonio')->__('Method'),
            'style' => 'width: 75px'
        ]);

        $this->addColumn('method_enabled', [
            'label' => Mage::helper('montonio')->__('On/Off'),
            'style' => 'width: 50px'
        ]);

        $this->addColumn('method_title', [
            'label' => Mage::helper('montonio')->__('Title'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_desc', [
            'label' => Mage::helper('montonio')->__('Description'),
            'style' => 'width: 200px'
        ]);

        $this->addColumn('method_sort', [
            'label' => Mage::helper('montonio')->__('Sort Order'),
            'style' => 'width: 50px'
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = Mage::helper('montonio')->__('Add label');

        parent::__construct();

        $this->setTemplate('montonio/split_array.phtml');
    }

    /**
     * @inheritdoc
     */
    protected function _renderCellTemplate($columnName)
    {
        if ($columnName != 'method_enabled') {
            return parent::_renderCellTemplate($columnName);
        }

        if (empty($this->_columns[$columnName])) {
            throw new Exception('Wrong column name specified.');
        }

        $column = $this->_columns[$columnName];
        $inputName = $this->getElement()->getName() . '[#{_id}][' . $columnName . ']';

        if ($column['renderer']) {
            return $column['renderer']->setInputName($inputName)
                ->setColumnName($columnName)
                ->setColumn($column)
                ->toHtml();
        }

        $options = [
            '0' => Mage::helper('montonio')->__('Off'),
            '1' => Mage::helper('montonio')->__('On')
        ];

        $optionsHtml = '';
        foreach ($options as $k => $v) {
            $optionsHtml .= '<option value="' . $k . '">' . $v  . '</option>';
        }
        $styleHtml = (isset($column['style']) ? ' style="' . $column['style'] . '"' : '');
        $cssHtml = (isset($column['class']) ? $column['class'] : 'input-select');
        $selectHtml = '<select data-selected-value="#{method_enabled}" name="' . $inputName . '" class="' . $cssHtml . '"' . $styleHtml . '>' . $optionsHtml . '</select>';

        return $selectHtml;
    }

    /**
     * @inheritdoc
     */
    protected function _prepareArrayRow(Varien_Object $row)
    {
    }

    /**
     * @inheritdoc
     */
    public function getArrayRows()
    {
        $values = $this->getElement()->getValue();

        if (!is_array($values)) {
            $values = [];
        }

        $splitMethods = [
            'split_1' => [
                'method_label'   => Montonio_Gateway_Model_Method_Split::SPLIT_METHOD_1,
                'method_title'   => 'Pay later',
                'method_desc'    => 'Pay in 1 month without any additional fees. 0% interest, 0 € contract fee and 0 € administration fee.',
                'method_enabled' => '1',
                'method_sort'    => 1000,
            ],
            'split_2' => [
                'method_label'   => Montonio_Gateway_Model_Method_Split::SPLIT_METHOD_2,
                'method_title'   => 'Pay in 2 instalments',
                'method_desc'    => 'Split your payment in 2 equal instalments without any additional fees. 0% interest, 0 € contract fee and 0 € administration fee.',
                'method_enabled' => '0',
                'method_sort'    => 1010,
            ],
            'split_3' => [
                'method_label'   => Montonio_Gateway_Model_Method_Split::SPLIT_METHOD_3,
                'method_title'   => 'Pay in 3 instalments',
                'method_desc'    => 'Split your payment in 3 equal instalments without any additional fees. 0% interest, 0 € contract fee and 0 € administration fee.',
                'method_enabled' => '1',
                'method_sort'    => 1020,
            ],
            'split_combined' => [
                'method_label'   => Montonio_Gateway_Model_Method_Split::SPLIT_METHOD_COMBINED,
                'method_title'   => 'Pay later',
                'method_desc'    => 'Split your payment in 1-3 equal instalments without any additional fees. 0% interest, 0 € contract fee and 0 € administration fee.',
                'method_enabled' => '0',
                'method_sort'    => 1030,
            ]
        ];

        $values = array_merge($splitMethods, $values);
        $this->getElement()->setValue($values);

        return parent::getArrayRows();
    }
}
